# chess-embedding
Python package for generating and applying chess embeddings

### Installation

1. Create virtual environment with python 3.7

2. Install chesspos package
`$ python -m pip install chesspos`

### Recommended workspace setup

For development:
check out the following packages 

For usage in embedding learning

### Bitboard generation

...

### Testing

- install pytest
- $ python -m pytest